==> zio-aws-nimble_2.12-5.17.295.16-sources.jar: zio/aws/nimble/model/ListStudioMembersRequest.scala <==
package zio.aws.nimble.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.nimble.model.primitives.MaxResults
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListStudioMembersRequest(
    maxResults: Optional[MaxResults] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent,
    studioId: String
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.nimble.model.ListStudioMembersRequest = {
    import ListStudioMembersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.nimble.model.ListStudioMembersRequest
      .builder()
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .studioId(studioId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.nimble.model.ListStudioMembersRequest.ReadOnly =
    zio.aws.nimble.model.ListStudioMembersRequest.wrap(buildAwsValue())
}
object ListStudioMembersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.nimble.model.ListStudioMembersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.nimble.model.ListStudioMembersRequest =
      zio.aws.nimble.model.ListStudioMembersRequest(
        maxResults.map(value => value),
        nextToken.map(value => value),
        studioId
      )
    def maxResults: Optional[MaxResults]
    def nextToken: Optional[String]
    def studioId: String
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getStudioId: ZIO[Any, Nothing, String] = ZIO.succeed(studioId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.nimble.model.ListStudioMembersRequest
  ) extends zio.aws.nimble.model.ListStudioMembersRequest.ReadOnly {
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.nimble.model.primitives.MaxResults(value))
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
    override val studioId: String = impl.studioId(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.nimble.model.ListStudioMembersRequest
  ): zio.aws.nimble.model.ListStudioMembersRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-nimble_2.13-5.17.102.7-sources.jar: zio/aws/nimble/model/ListStudioMembersRequest.scala <==
package zio.aws.nimble.model
import java.lang.Integer
import zio.aws.nimble.model.primitives.MaxResults
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListStudioMembersRequest(
    maxResults: Option[MaxResults] = None,
    nextToken: Option[String] = None,
    studioId: String
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.nimble.model.ListStudioMembersRequest = {
    import ListStudioMembersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.nimble.model.ListStudioMembersRequest
      .builder()
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .studioId(studioId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.nimble.model.ListStudioMembersRequest.ReadOnly =
    zio.aws.nimble.model.ListStudioMembersRequest.wrap(buildAwsValue())
}
object ListStudioMembersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.nimble.model.ListStudioMembersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.nimble.model.ListStudioMembersRequest =
      zio.aws.nimble.model.ListStudioMembersRequest(
        maxResults.map(value => value),
        nextToken.map(value => value),
        studioId
      )
    def maxResults: Option[MaxResults]
    def nextToken: Option[String]
    def studioId: String
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getStudioId: ZIO[Any, Nothing, String] = ZIO.succeed(studioId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.nimble.model.ListStudioMembersRequest
  ) extends zio.aws.nimble.model.ListStudioMembersRequest.ReadOnly {
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.nimble.model.primitives.MaxResults(value))
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
    override val studioId: String = impl.studioId(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.nimble.model.ListStudioMembersRequest
  ): zio.aws.nimble.model.ListStudioMembersRequest.ReadOnly = new Wrapper(impl)
}
